==> gnome-panel-2.3.1.tar.bz2: gnome-panel-2.3.1/gnome-panel/panel-xutils.h <==
/*
 * panel-xutils.h: X related utility methods.
 *
 * Copyright (C) 2003 Sun Microsystems, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Authors:
 *	Mark McLoughlin <mark@skynet.ie>
 */

#ifndef __PANEL_XUTILS_H__
#define __PANEL_XUTILS_H__

#include <glib/gmacros.h>
#include <glib/gtypes.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>

#include <X11/Xlib.h>

G_BEGIN_DECLS

typedef enum {
	PANEL_XUTILS_TYPE_NORMAL,
	PANEL_XUTILS_TYPE_DOCK,
} PanelXUtilsWindowType;

void panel_xutils_set_window_type (GdkWindow             *gdk_window,
				   PanelXUtilsWindowType  type);

void panel_xutils_set_strut       (GdkWindow             *gdk_window,
				   guint32                left,
				   guint32                right,
				   guint32                bottom,
				   guint32                top);

void panel_warp_pointer           (GdkWindow             *gdk_window,
				   int                    x,
				   int                    y);

G_END_DECLS

#endif /* __PANEL_XUTILS_H__ */

==> gnome-panel-2.8.0.1.tar.bz2: gnome-panel-2.8.0.1/gnome-panel/panel-xutils.h <==
/*
 * panel-xutils.h: X related utility methods.
 *
 * Copyright (C) 2003 Sun Microsystems, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 *
 * Authors:
 *	Mark McLoughlin <mark@skynet.ie>
 */

#ifndef __PANEL_XUTILS_H__
#define __PANEL_XUTILS_H__

#include <glib/gmacros.h>
#include <glib/gtypes.h>
#include <gdk/gdk.h>
#include <gdk/gdkx.h>

#include <X11/Xlib.h>

#include "panel-enums.h"

G_BEGIN_DECLS

typedef enum {
	PANEL_XUTILS_TYPE_NORMAL,
	PANEL_XUTILS_TYPE_DOCK
} PanelXUtilsWindowType;

void panel_xutils_set_window_type (GdkWindow             *gdk_window,
				   PanelXUtilsWindowType  type);

void panel_xutils_set_strut       (GdkWindow             *gdk_window,
				   PanelOrientation       orientation,
				   guint32                strut,
				   guint32                strut_start,
				   guint32                strut_end);

void panel_warp_pointer           (GdkWindow             *gdk_window,
				   int                    x,
				   int                    y);

/* FIXME: When we switch to gtk+-2.6, use of this function should be
 * replaced by using the real gdk_x11_window_set_user_time.
 */
void panel_gdk_x11_window_set_user_time (GdkWindow *window,
					 guint32    timestamp);

G_END_DECLS

#endif /* __PANEL_XUTILS_H__ */
